@@ -471,6 +471,11 @@ class ChannelPack(object):
             In iteration of the generator if any of the names used for
             the namedtuple is invalid python identifiers.
 
+        Note
+        ----
+        Either there must be names defined in the pack or argument
+        `fallback` must be True, else there will be no records.
+
         """
 
         names = [self.names[key] for key in sorted(self.names)]
@@ -565,7 +570,10 @@ class ChannelPack(object):
         elif firstwordonly is True:
             return self.names[key].split()[0]
         elif type(firstwordonly) is str:
-            return re.findall(firstwordonly, self.names[key])[0]
+            mlist = re.findall(firstwordonly, self.names[key])
+            if mlist:
+                return mlist[0]
+            raise ValueError('No match with regex: {}'.format(firstwordonly))
         else:
             raise TypeError(firstwordonly)
 
