@@ -7,7 +7,9 @@ import re
 from collections import namedtuple, defaultdict
 import io
 import locale
+import string
 
+import numpy as np
 from . import pack as cp
 
 # The scanf kind of regular expressions as suggested by python docs
@@ -26,12 +28,12 @@ def _escape(s):
 
 def _floatit(s):
     """Replace ',' with '.' and convert to float."""
-    return float(s.replace(',', '.'))
+    return float(s.replace(',', '.')) if s else np.nan
 
 
 def _floatit_bytes(b):
     """Replace b',' with b'.' and convert to float."""
-    return float(b.replace(b',', b'.'))
+    return float(b.replace(b',', b'.')) if b else np.nan
 
 
 def preparse(lines, firstfieldrx=r'\w'):
@@ -256,11 +258,10 @@ def lazy_textpack(fname, parselines=25, **textkwargs):
         keyword arguments if duplicated.
 
     """
-    with contextopen(fname) as context:
+    encoding = textkwargs.get('encoding', locale.getpreferredencoding())
+    with contextopen(fname, encoding=encoding) as context:
         fo = context.fo
         if context.bytehint:
-            encoding = textkwargs.get('encoding',
-                                      locale.getpreferredencoding())
             derived = preparse([fo.readline().decode(encoding)
                                 for i in range(parselines)])
             if derived and derived['delimiter'] is not None:
@@ -399,7 +400,7 @@ def textpack(fname, names=None, delimiter=None, skiprows=0, usecols=None,
 
         return columndata
 
-    with contextopen(fname) as context:
+    with contextopen(fname, encoding=encoding) as context:
         fo = context.fo
         if context.bytehint:
             bytehint = encoding or True
@@ -430,9 +431,9 @@ def linetuples(fo, bytehint=False, delimiter=None, usecols=None,
     # usecols is a sequence to this function
 
     # bytehint argument: True means bytes are coming in, but don't
-    # decode them. A string means bytes are coming in and the string is
-    # a codec for decoding them. With bytes io the given delimiter must
-    # be byte(s)
+    # decode them. A string means bytes are coming in and the string
+    # is a codec for decoding them (textual results). With bytes io
+    # the given delimiter must be byte(s)
 
     # stripstrings True means to strip white space from things that are
     # not numeric data.
@@ -454,27 +455,38 @@ def linetuples(fo, bytehint=False, delimiter=None, usecols=None,
     def as_is_stripped_decode(b):
         return b.strip().decode(encoding)
 
+    def maybenan(s):
+        return float(s) if s else np.nan
+
+    # don't strip off tabs or some possible white space delimiter
+    if not bytehint:
+        stripchars = string.whitespace.replace(delimiter or '\t', '')
+    elif bytehint:
+        whites = string.whitespace.encode('ascii')
+        # assuming delimiter is bytes or None
+        stripchars = whites.replace(delimiter or b'\t', b'')
+
     if hasnames:
         fieldnames = [field.strip() for field in
-                      fo.readline().strip().split(delimiter)]
+                      fo.readline().strip(stripchars).split(delimiter)]
         namesfunc = (as_is_stripped if not type(bytehint) is str
                      else as_is_stripped_decode)
 
-    firstvals = fo.readline().strip().split(delimiter)  # delimiter bytes?
+    firstvals = fo.readline().strip(stripchars).split(delimiter)  # bytes?
     funcs = []
     for val in firstvals:
         try:
             float(val)          # works with bytes too
-            funcs.append(float)
+            funcs.append(maybenan)
             continue
         except ValueError:
             pass
         try:
             if not bytehint:
-                _floatit(val)
+                float(val.replace(',', '.'))  # test
                 funcs.append(_floatit)
             else:
-                _floatit_bytes(val)
+                float(val.replace(b',', b'.'))  # test
                 funcs.append(_floatit_bytes)
             continue
         except ValueError:
@@ -494,7 +506,7 @@ def linetuples(fo, bytehint=False, delimiter=None, usecols=None,
     # with numbers that are 0, the usual float succeed.
     decfloatfunc = _floatit if not bytehint else _floatit_bytes
     if decfloatfunc in funcs:
-        funcs = [decfloatfunc if func is float else func for func in funcs]
+        funcs = [decfloatfunc if func is maybenan else func for func in funcs]
 
     # Replace functions with caller functions if any
     if converters:
@@ -515,7 +527,7 @@ def linetuples(fo, bytehint=False, delimiter=None, usecols=None,
                 zip(funcs, firstvals, allcols) if col in usecols)
 
     for line in fo:
-        stripped = line.strip()
+        stripped = line.strip(stripchars)
         if not stripped:
             continue
         yield tuple(func(val) for func, val, col in
